# Build

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**base_image** | **str** | Name of base image used by the s2i build.  | [optional]
**output_image** | **str** | Name of output image - can also specify remote registry to pull image from.  | [optional]
**build_log** | [**BuildBuildLog**](BuildBuildLog.md) |  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
